@@ -118,6 +118,7 @@ pub(crate) fn get_ascii_art(small: bool) -> Vec<Text<'static>> {
         Span::styled(" ooo  oo  ooo  ", *GREEN),
         Span::styled(" oooooooooooo  ", *GREEN),
     ];
+
     vec![Text::from(
         art.iter()
             .map(|f| Spans::from(f.to_owned()))
@@ -246,6 +247,23 @@ pub(crate) fn get_ascii_art(small: bool) -> Vec<Text<'static>> {
     vec![Text::from(art)]
 }
 
+#[cfg(target_os = "freebsd")]
+pub(crate) fn get_ascii_art(small: bool) -> Vec<Text<'static>> {
+    // The following ASCII art was made by Dylan Araps
+    // and taken from https://github.com/dylanaraps/pfetch
+
+    let art: Vec<Spans> = vec![
+        Spans::from(vec![Span::styled("/\\,-'''''-,/\\", *RED)]),
+        Spans::from(vec![Span::styled("\\_)       (_//", *RED)]),
+        Spans::from(vec![Span::styled(" |           |", *RED)]),
+        Spans::from(vec![Span::styled(" |           |", *RED)]),
+        Spans::from(vec![Span::styled("  ;         ;", *RED)]),
+        Spans::from(vec![Span::styled("   '-_____-'", *RED)]),
+    ];
+
+    vec![Text::from(art)]
+}
+
 #[cfg(target_os = "netbsd")]
 pub(crate) fn get_ascii_art(small: bool) -> Vec<Text<'static>> {
     if !small {
