@@ -191,6 +191,9 @@ pub struct Opt {
     #[structopt(short = "S", long = "long-shell", help = "Lengthens shell output")]
     pub long_shell: bool,
 
+    #[structopt(short = "k", long = "long-kernel", help = "Lengthens kernel output")]
+    pub long_kernel: bool,
+
     #[structopt(
         short = "W",
         long = "current-shell",
@@ -277,6 +280,13 @@ pub struct Opt {
     )]
     #[serde(skip_serializing, skip_deserializing)]
     pub config: Option<std::path::PathBuf>,
+
+    #[structopt(
+        long = "interface",
+        short = "i",
+        help = "Specify the network interface"
+    )]
+    pub interface: Option<String>,
 }
 
 impl Default for Opt {
@@ -309,7 +319,9 @@ impl Default for Opt {
             doctor: false,
             short_uptime: false,
             long_shell: false,
+            long_kernel: true,
             current_shell: false,
+            interface: None,
             theme: None,
             box_title: None,
             box_inner_margin_x: 1,
